=== modified file 'plugin/query_log/file.cc'
--- plugin/query_log/file.cc	2011-06-25 15:06:32 +0000
+++ plugin/query_log/file.cc	2011-07-30 20:43:56 +0000
@@ -18,27 +18,14 @@
  */
 
 #include <config.h>
-#include <string>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include "file.h"
 
 using namespace std;
 
 QueryLoggerFile::QueryLoggerFile()
 {
-  _fd= LOG_FILE_CLOSED;
-
-  // If you add something here, the number of params must match the number
-  // of values pushed to the formatter in logEvent().
-  _formatter.parse(
-    "# %s\n"
-    "# session_id=%d query_id=%d rows_examined=%d rows_sent=%d tmp_tables=%d warnings=%d\n"
-    "# execution_time=%.6f lock_time=%.6f session_time=%.6f\n"
-    "# error=%s\n"
-    "# schema=\"%s\"\n"
-    "%s;\n#\n"
-  );
+  _fh.setf(ios::fixed, ios::floatfield);
+  _fh.precision(6);
 }
 
 QueryLoggerFile::~QueryLoggerFile()
@@ -48,50 +35,49 @@
 
 bool QueryLoggerFile::logEvent(const event_t *event)
 {
-  if (_fd == LOG_FILE_CLOSED)
-    return false;
-
-  _formatter
-    % event->ts
-    % event->session_id
-    % event->query_id
-    % event->rows_examined
-    % event->rows_sent
-    % event->tmp_tables
-    % event->warnings
-    % event->execution_time
-    % event->lock_time  // broken
-    % event->session_time
-    % event->error
-    % event->schema
-    % event->query;
-  string msgbuf= _formatter.str();
-
-  size_t wrv;
-  wrv= write(_fd, msgbuf.c_str(), msgbuf.length());
-  assert(wrv == msgbuf.length());
-
+  if (_fh.is_open())
+  {
+    _fh << "# " << event->ts << "\n"
+        << "# session_id="     << event->session_id
+        <<  " query_id="       << event->query_id
+        <<  " rows_examined="  << event->rows_examined
+        <<  " rows_sent="      << event->rows_sent
+        <<  " tmp_tables="     << event->tmp_tables
+        <<  " warnings="       << event->warnings
+        << "\n"
+        << "# execution_time=" << event->execution_time
+        <<  " lock_time="      << event->lock_time
+        <<  " session_time="   << event->session_time
+        << "\n"
+        << "# error=" << event->error << "\n"
+        << "# schema=\"" << event->schema << "\"\n"
+        << event->query << ";\n#"
+        << endl;
+  }
   return false; // success
 }
 
 bool QueryLoggerFile::openLogFile(const char *file)
 {
   assert(file != NULL);
- 
-  int new_fd= open(file, O_WRONLY | O_APPEND | O_CREAT, S_IRUSR | S_IWUSR);
-  if (new_fd < 0)
+
+  closeLogFile();
+
+  _fh.open(file, ios::app);
+  if (_fh.fail())
     return true; // error
 
-  closeLogFile();
-  _fd= new_fd;
-
   return false; // success
 }
 
 bool QueryLoggerFile::closeLogFile()
 {
-  if (not _fd == LOG_FILE_CLOSED)
-    close(_fd);  // TODO: catch errors
-  _fd= LOG_FILE_CLOSED;
+  if (_fh.is_open())
+  {
+    _fh.close();
+    if (_fh.fail())
+      return true;  // error
+  }
+
   return false;  // success
 }

=== modified file 'plugin/query_log/file.h'
--- plugin/query_log/file.h	2011-05-21 00:14:19 +0000
+++ plugin/query_log/file.h	2011-07-30 20:43:56 +0000
@@ -17,11 +17,10 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <boost/format.hpp>
+#include <iostream>
+#include <fstream>
 #include "event.h"
 
-#define LOG_FILE_CLOSED -1
-
 /**
  * @brief
  *   QueryLoggerFile implements logging to a file for the QueryLog class.
@@ -86,6 +85,5 @@
   bool closeLogFile();
 
 private:
-  int _fd;                   ///< File descriptor for open log file
-  boost::format _formatter;  ///< Log file format printer
+  std::ofstream _fh;  ///< File handle for open log file
 };

